==> modonomicon-1.20.1-fabric-1.79.1-sources.jar: com/klikli_dev/modonomicon/book/conditions/BookNoneCondition.java <==
/*
 * SPDX-FileCopyrightText: 2022 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.book.conditions;

import com.google.gson.JsonObject;
import com.klikli_dev.modonomicon.api.ModonomiconConstants.Data.Condition;
import com.klikli_dev.modonomicon.book.conditions.context.BookConditionContext;
import net.minecraft.class_1657;
import net.minecraft.class_2540;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_5250;

/**
 * The default condition - equivalent to the True condition, but will be replaced by AddAutoReadConditions
 */
public class BookNoneCondition extends BookCondition {

    public BookNoneCondition() {
        this(null);
    }

    public BookNoneCondition(class_2561 component) {
        super(component);
    }

    public static BookNoneCondition fromJson(JsonObject json) {
        var tooltip = tooltipFromJson(json);
        return new BookNoneCondition(tooltip);
    }

    public static BookNoneCondition fromNetwork(class_2540 buffer) {
        var tooltip = buffer.readBoolean() ? buffer.method_10808() : null;
        return new BookNoneCondition(tooltip);
    }

    @Override
    public class_2960 getType() {
        return Condition.NONE;
    }

    @Override
    public void toNetwork(class_2540 buffer) {
        buffer.writeBoolean(this.tooltip != null);
        if (this.tooltip != null) {
            buffer.method_10805(this.tooltip);
        }
    }

    @Override
    public boolean test(BookConditionContext context, class_1657 player) {
        return true;
    }
}

==> modonomicon-1.21.1-fabric-1.117.1-sources.jar: com/klikli_dev/modonomicon/book/conditions/BookNoneCondition.java <==
/*
 * SPDX-FileCopyrightText: 2022 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.book.conditions;

import com.google.gson.JsonObject;
import com.klikli_dev.modonomicon.api.ModonomiconConstants.Data.Condition;
import com.klikli_dev.modonomicon.book.conditions.context.BookConditionContext;
import net.minecraft.class_1657;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_5250;
import net.minecraft.class_7225;
import net.minecraft.class_8824;
import net.minecraft.class_9129;

/**
 * The default condition - equivalent to the True condition, but will be replaced by AddAutoReadConditions
 */
public class BookNoneCondition extends BookCondition {

    public BookNoneCondition() {
        this(null);
    }

    public BookNoneCondition(class_2561 component) {
        super(component);
    }

    public static BookNoneCondition fromJson(class_2960 conditionParentId, JsonObject json, class_7225.class_7874 provider) {
        var tooltip = tooltipFromJson(json, provider);
        return new BookNoneCondition(tooltip);
    }

    public static BookNoneCondition fromNetwork(class_9129 buffer) {
        var tooltip = buffer.readBoolean() ? class_8824.field_48540.decode(buffer) : null;
        return new BookNoneCondition(tooltip);
    }

    @Override
    public class_2960 getType() {
        return Condition.NONE;
    }

    @Override
    public void toNetwork(class_9129 buffer) {
        buffer.method_52964(this.tooltip != null);
        if (this.tooltip != null) {
            class_8824.field_48540.encode(buffer, this.tooltip);
        }
    }

    @Override
    public boolean test(BookConditionContext context, class_1657 player) {
        return true;
    }
}
